@@ -359,8 +359,10 @@ KServiceGroupPrivate::entries(KServiceGroup *group, bool sort, bool excludeNoDis
     // together with the entries. We can't only load the entries afterwards
     // since the offsets could have been changed if the database has changed.
 
+    KServiceGroup::Ptr grp;
     if (!m_bDeep) {
-        KServiceGroup::Ptr grp = KServiceGroupFactory::self()->findGroupByDesktopPath(path, true);
+        grp = KServiceGroupFactory::self()->findGroupByDesktopPath(path, true);
+
         group = grp.data();
         if (0 == group) { // No guarantee that we still exist!
             return KServiceGroup::List();
@@ -652,14 +654,6 @@ QStringList KServiceGroup::layoutInfo() const
     return d->sortOrder;
 }
 
-#ifndef KDE_NO_DEPRECATED
-KServiceGroup::Ptr
-KServiceGroup::baseGroup(const QString &_baseGroupName)
-{
-    return KServiceGroupFactory::self()->findBaseGroup(_baseGroupName, true);
-}
-#endif
-
 KServiceGroup::Ptr
 KServiceGroup::root()
 {
